@@ -19,7 +19,7 @@ module Asciidoctor
         when Options
           @options = first_option
         when ::Hash
-          @options = Options.new options
+          @options = Options.new first_option
         else
           if ::Integer === (result = Options.parse! options)
             @code = result
@@ -42,6 +42,8 @@ module Asciidoctor
         non_posix_env = ::File::ALT_SEPARATOR == RS
         err = @err || $stderr
         show_timings = false
+        # NOTE in Ruby 2.7, RubyGems sets SOURCE_DATE_EPOCH if it's not set
+        ::ENV.delete 'SOURCE_DATE_EPOCH' if (::ENV.key? 'IGNORE_SOURCE_DATE_EPOCH') && (::Gem.respond_to? :source_date_epoch)
 
         @options.map do |key, val|
           case key
@@ -86,7 +88,7 @@ module Asciidoctor
         end
 
         if outfile == '-'
-          tofile = @out || $stdout
+          (tofile = @out) || ((tofile = $stdout).set_encoding UTF_8)
         elsif outfile
           opts[:mkdirs] = true
           tofile = outfile
@@ -97,7 +99,8 @@ module Asciidoctor
 
         if stdin
           # allows use of block to supply stdin, particularly useful for tests
-          input = block_given? ? yield : STDIN
+          # NOTE set_encoding returns nil on JRuby 9.1
+          block_given? ? (input = yield) : ((input = $stdin).set_encoding UTF_8, UTF_8)
           input_opts = opts.merge to_file: tofile
           if show_timings
             @documents << (::Asciidoctor.convert input, (input_opts.merge timings: (timings = Timings.new)))
@@ -139,7 +142,7 @@ module Asciidoctor
             raise e
           else
             err.puts ::RuntimeError === e ? %(#{e.message} (#{e.class})) : e.message
-            err.puts '  Use --trace for backtrace'
+            err.puts '  Use --trace to show backtrace'
           end
         end
         nil
